@@ -1,6 +1,6 @@
 package Term::ANSIColor::Concise;
 
-our $VERSION = "2.0201";
+our $VERSION = "2.03";
 
 use v5.14;
 use warnings;
@@ -241,6 +241,7 @@ use constant {
 };
 
 my %csi_terminator = (
+    ICH => '@',	 # Insert Character
     CUU => 'A',	 # Cursor up
     CUD => 'B',	 # Cursor Down
     CUF => 'C',	 # Cursor Forward
@@ -251,8 +252,12 @@ my %csi_terminator = (
     CUP => 'H',	 # Cursor Position
     ED  => 'J',	 # Erase in Display (0 after, 1 before, 2 entire, 3 w/buffer)
     EL  => 'K',	 # Erase in Line (0 after, 1 before, 2 entire)
+    IL  => 'L',	 # Insert Line
+    DL  => 'M',	 # Delete Line
+    DCH => 'P',	 # Delete Character
     SU  => 'S',	 # Scroll Up
     SD  => 'T',	 # Scroll Down
+    ECH => 'X',	 # Erase Character
     HVP => 'f',	 # Horizontal Vertical Position
     SGR => 'm',	 # Select Graphic Rendition
     SCP => 's',	 # Save Cursor Position
@@ -362,9 +367,9 @@ sub apply_color {
 	my($s, $e, $el) = @{ $cache->{$color} //= [ ansi_pair($color) ] };
 	state $reset = qr{ \e\[[0;]*m (?: \e\[[0;]*[Km] )* }x;
 	if ($el) {
-	    $text =~ s/(\A|(?<=[\r\n])|$reset)([^\e\r\n]*)/${1}${s}${2}${e}/mg;
+	    $text =~ s/(\A|(?<=[\r\n])|$reset)\K(?<x>[^\e\r\n]+|(?<!\n))/${s}$+{x}${e}/mg;
 	} else {
-	    $text =~ s/(\A|(?<=[\r\n])|$reset)([^\e\r\n]+)/${1}${s}${2}${e}/mg;
+	    $text =~ s/(\A|(?<=[\r\n])|$reset)\K(?<x>[^\e\r\n]+)/${s}$+{x}${e}/mg;
 	}
 	return $text;
     }
@@ -401,7 +406,7 @@ Term::ANSIColor::Concise - Produce ANSI terminal sequence by concise notation
 
 =head1 VERSION
 
-Version 2.0201
+Version 2.03
 
 
 =head1 DESCRIPTION
@@ -605,6 +610,7 @@ section for detail.
 Native CSI (Control Sequence Introducer) sequences in the form of
 C<{NAME}>.
 
+    ICH n   Insert Character
     CUU n   Cursor up
     CUD n   Cursor Down
     CUF n   Cursor Forward
@@ -615,8 +621,12 @@ C<{NAME}>.
     CUP n,m Cursor Position
     ED  n   Erase in Display (0 after, 1 before, 2 entire, 3 w/buffer)
     EL  n   Erase in Line (0 after, 1 before, 2 entire)
+    IL  n   Insert Line
+    DL  n   Delete Line
+    DCH n   Delete Character (scroll rest to left)
     SU  n   Scroll Up
     SD  n   Scroll Down
+    ECH n   Erase Character
     HVP n,m Horizontal Vertical Position
     SGR n*  Select Graphic Rendition
     SCP     Save Cursor Position
